/*

This do-file replicates the specialization regressions from di Giovanni and Levchenko,

"Trade Openness and Volatility," REStat 2009.

In particular, Tables 8 and C7, and Figure 4.
*/


set more off

use herfdata, clear

******* MAIN TABLE **************************************

reg  lherf ltrade2output, r
reg  lherf ltrade2output lrgdpl, r
ivreg  lherf (ltrade2output = logfrank), r
ivreg  lherf lrgdpl (ltrade2output = logfrank), r
reg  lherf ltrade2output lherfx lrgdpl, r
ivreg  lherf lrgdpl lherfx (ltrade2output = logfrank), r


 ******* ROBUSTNESS TABLE **********************************

ivreg  lherf lrgdpl lherfx (ltrade2output = logfrank) if lherf<-1.15 & lherf>-2.77, r
qui reg lherf ltrade2output lrgdpl, r
reg lherf lopenc lherfx lrgdpl if e(sample), r
qui reg  lherf ltrade2output lrgdpl, r
ivreg  lherf lrgdpl lherfx (lopenc = logfrank) if e(sample), r

replace rgdpl=rgdpl/1000
replace pop=pop/1000
ge rgdpl2 = rgdpl^2
ge lrgdpl2 = lrgdpl^2 
ivreg  lherf lherfx lrgdpl ldisteq mining agro (ltrade2output = logfrank), r

ivreg  lherf lherfx lrgdpl ldisteq mining agro meantp frstdays tropics (ltrade2output = logfrank), r
ivreg  lherf lherfx lrgdpl ldisteq mining agro eap - ssa (ltrade2output = logfrank), r 
ivreg  lherf lherfx lrgdpl lrgdpl2 RS_incm density lpop ldistantness mining agro (ltrade2output = logfrank), r 
outreg using TableC7.out, append coef 10pct nolabel se rdec(4) ctitle(IV) 

*****************************************************************************************
*  FIGURE 4																			
*****************************************************************************************

****** PLOT OF PARTIAL CORRELATIONS ******************

reg  lherf lrgdpl, r

predict lherfresids if e(sample), resid

reg ltrade2output lrgdpl, r
predict openresids if e(sample), resid

reg  lherfresids openresids, r
predict lherfpredict if e(sample)

twoway (scatter lherfresids openresids, msymbol(none) mlabel(wbcode)) (line lherfpredict openresids), ytitle(Log(Herfindahl of Production Shares)) xtitle(Log(Trade/GDP)) legend(off)

